# add a start menu shortcut
case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
/usr/bin/mkshortcut $CYGWINFORALL -P -i /usr/bin/xlaunch.exe -n "Cygwin-X${wow64}/XLaunch" -a "/usr/bin/bash.exe -l -c /usr/bin/xlaunch.exe" /usr/bin/run.exe

# add file association for opening and editing .xlaunch files
/usr/share/xlaunch/setupreg.sh add
