# remove start menu shortcut
case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
rm -f "$(cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/XLaunch.lnk"
rmdir --ignore-fail-on-non-empty "$(cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"

# remove file association for opening and editing .xlaunch files
/usr/share/xlaunch/setupreg.sh remove

